==> haskell-test-framework-smallcheck-0.2-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-FadZHSgKTce8T696cele1E
key: test-framework-smallcheck-0.2-FadZHSgKTce8T696cele1E
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: 3a4516d5b0e736fb8d376ec352e4981e
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.3/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-FadZHSgKTce8T696cele1E
depends:
    base-4.12.0.0 smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
    test-framework-0.8.2.0-Bt2cnRgWAY3QQnnHA1ys2 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-7bNwNGXXmdXGJ1QebCWGfQ
key: test-framework-smallcheck-0.2-7bNwNGXXmdXGJ1QebCWGfQ
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: 2dc56898ba99a3f2675e22904df336d6
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.4/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-7bNwNGXXmdXGJ1QebCWGfQ
depends:
    base-4.12.0.0 smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
    test-framework-0.8.2.0-Bt2cnRgWAY3QQnnHA1ys2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
